pytilities.overloading

Package pytilities :: Package overloading |
[hide private]
[frames] | no frames]

# Package overloading

source code

Function overloading tools.

Classes:

> Parameter
>   A parameter of an operation.
> Param
>   Alias for Parameter
> CompositeParameter
>   Parameter that consists of more parameters.
> CompositeParam
>   Alias for CompositeParameter
> Overloader
>   A collection of `Overload`s that can process calls.
> Overload
>   An operation signature with an operation to call when arguments match.

Decorators:

> overloaded
>   Overloads an operation.

Submodules | [hide private]
pytilities.overloading.compositeparameter pytilities.overloading.decorators pytilities.overloading.matchers pytilities.overloading.overload pytilities.overloading.overloader pytilities.overloading.parameter

Variables | [hide private]
| __package__ = ``'``pytilities.overloading``'``